# lgm

Lightweight python3 library for natural LanGuage Modeling (LGM). Mostly useful for DL/RL experiments with natural language data. [originally based on the fastai course v3, dl2 (March-April 2019)].

To install:

pip3 install lgm
